============================
django-transaction-hooks
============================

This project has been merged into Django and is now core functionality in
all supported versions of Django. Use the version built-in to Django; this
standalone app is unmaintained.
